@@ -24,7 +24,7 @@
 #' }
 #'
 
-get_ts <- function(id, type, metadata, cl, verbose){
+get_ts <- function(id, type, metadata = FALSE, cl = NULL, verbose = FALSE){
 
   options(warn=-1)                                       # do not print warnings
 
@@ -60,6 +60,7 @@ get_ts <- function(id, type, metadata, cl, verbose){
                                         X = as.list(id),
                                         fun = get_ts_internal,
                                         type, metadata, verbose)
+          names(tsList) <- id
 
         }else{
           stop('cl is not a cluster object!')
